@@ -10,7 +10,7 @@ seqLLCS <- function(seq1,seq2) {
 	l1 <- seqlength(seq1)
 	l2 <- seqlength(seq2)
 
-	result <- .C("cLCS", as.integer(seq1), as.integer(seq2), as.double(c(l1,l2)), result = as.integer(0), PACKAGE="TraMineR")$result
+	result <- .C(TMR_cLCS, as.integer(seq1), as.integer(seq2), as.double(c(l1,l2)), result = as.integer(0))$result
 	
 	return(result)
 }
