@@ -116,4 +116,20 @@ print.seqe<-function(x,quote = FALSE,...){
 print.seqelist<-function(x,quote = FALSE,...){
   x<-as.character(x)
   print(x,quote=quote,...)
-}
\ No newline at end of file
+}
+
+## ========================================
+## Plot sequences
+## ========================================
+
+plot.seqe <- function(x, type = "pc", ...) {
+  if (type == "pc") {
+    seqpcplot(x, ...)
+  }
+}
+
+plot.seqelist <- function(x, type = "pc", ...) {
+  if (type == "pc") {
+    seqpcplot(x, ...)
+  }
+}
